import {Command} from "ckeditor5/src/core";

export default class InsertBlockCommand extends Command {
  execute(options) {
    const editor = this.editor;
    const model = editor.model;

    const { class: blockClass, library, block_id, position } = options;

    model.change((writer) => {
      const range = writer.createRange(position, position.getShiftedBy(1));

      // Check block has class insert-block and has data-block-id
      const blockElement = Array.from(range.getItems()).find((item) => {
        if (item.is('element') && item.getAttribute('htmlDivAttributes')) {
          const attributes = item.getAttribute('htmlDivAttributes');
          return (
            attributes &&
            attributes.classes.includes('insert-block') &&
            attributes.attributes['data-block-id'] === block_id
          );
        }
        return false;
      });

      if (blockElement) {
        // Get current attributes.
        const currentAttributes = blockElement.getAttribute('htmlDivAttributes') || {};
        const updatedAttributes = {
          ...currentAttributes,
          classes: [blockClass, ...(currentAttributes.classes || [])],
          attributes: {
            ...(currentAttributes.attributes || {}),
            'data-library': library,
          },
        };
        // Add attributes.
        writer.setAttribute('htmlDivAttributes', updatedAttributes, blockElement);
      } else {
        console.error('Block element not found at the specified position.');
      }
    });
  }


  refresh() {
    const {model} = this.editor;
    const {selection} = model.document;
    const allowedIn = model.schema.findAllowedParent(
      selection.getFirstPosition(),
      'insertBlocks',
    );
    this.isEnabled = allowedIn !== null;
  }

}

