<?php

namespace Drupal\ckeditor_insert_blocks\Controller;

use Drupal\Core\Block\BlockManagerInterface;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Render\RendererInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Response;

/**
 * Returns responses for Ckeditor insert blocks routes.
 */
class InsertBlockController extends ControllerBase {

  /**
   * The controller constructor.
   */
  public function __construct(
    protected BlockManagerInterface $blockManager,
    protected RendererInterface $renderer,
  ) {}

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): self {
    return new self(
      $container->get('plugin.manager.block'),
      $container->get('renderer'),
    );
  }

  /**
   * Show block content.
   *
   * @inheritDoc
   */
  public function showBlockContent($block_id = '') {
    if (empty($block_id)) {
      return new Response('');
    }
    $currentUser = $this->currentUser();
    $build = $this->renderBlock($currentUser, $block_id);
    return new Response($this->renderer->render($build));
  }

  /**
   * Render block with current user and block id.
   *
   * @inheritDoc
   */
  public function renderBlock($currentUser, $delta) {
    $plugin_block = $this->blockManager->createInstance($delta, []);
    $render = '';
    if ($plugin_block->access($currentUser)) {
      $render = $plugin_block->build();
      if (!empty($render["#view"]) && empty($render["#view"]->result)) {
        return FALSE;
      }
      if (empty($render)) {
        return FALSE;
      }
    }

    return $render;
  }

}
